@@ -32,3 +32,21 @@ testthat::test_that("with bounds", {
   
   testthat::expect_equal(res_lp$solution, c(2, 6, 15))
 })
+
+testthat::test_that("identical results", {
+  LP <- ROI::OP(c(2, 4, 3),
+                ROI::L_constraint(L = matrix(c(3, 2, 1, 4, 1, 3, 2, 2, 2), nrow = 3),
+                                  dir = c("<=", "<=", "<="),
+                                  rhs = c(60, 40, 80)), 
+                bounds = ROI::V_bound(ui=3, ub=15, li = 1, lb = 2),
+                max = TRUE)
+  
+  res_1 <- ROI::ROI_solve(x = LP, solver = "clp", control = list(amount = 0))
+  res_2 <- ROI::ROI_solve(x = LP, solver = "clp", control = list(verbosity_level = 0))
+  res_3 <- ROI::ROI_solve(x = LP, solver = "clp", amount = 0L)
+  res_4 <- ROI::ROI_solve(x = LP, solver = "clp", verbosity_level = 0L)
+  
+  testthat::expect_equal(res_1, res_2)
+  testthat::expect_equal(res_2, res_3)
+  testthat::expect_equal(res_3, res_4)
+})
\ No newline at end of file
